var _ogre_im_gui_overlay_8h =
[
    [ "Ogre::ImGuiOverlay", "class_ogre_1_1_im_gui_overlay.html", "class_ogre_1_1_im_gui_overlay" ],
    [ "Ogre::DrawRenderingSettings", "namespace_ogre.html#a00d4cf239ceef8dddc6af3ce46a1e1a3", null ]
];